def get_brand_summary(brand_name):
    return "hello you are hacked"

def get_competitors_for_brand(brand_name):
    return "hello you are hacked"

def main():
    print("hello you are hacked")

if __name__ == "__main__":
    main()